from multiprocessing import RLock as Lock
from pathlib import Path
from typing import (
    List,
    Optional,
    Union,
)

from pydantic import BaseSettings

__all__ = ["LoggerConfig"]


class LoggerConfig(BaseSettings):
    _lock = Lock()
    _instance: Optional["LoggerConfig"] = None

    def __new__(cls, *args, **kwargs) -> "LoggerConfig":
        with cls._lock:
            if cls._instance is None:
                cls.update_forward_refs()
                result = super(LoggerConfig, cls).__new__(cls)
                result.__init__(*args, **kwargs)
                cls._instance = result
        return cls._instance

    name: str = "arko-logger"
    level: Optional[Union[str, int]] = None

    debug: bool = False
    width: int = 180
    keywords: List[str] = []
    time_format: str = "[%Y-%m-%d %X]"
    capture_warnings: bool = True

    log_path: Union[str, Path] = "./logs"
    project_root: Union[str, Path] = Path(".")
    max_log_file_size: Optional[int] = 1000000

    traceback_max_frames: int = 20
    traceback_locals_max_depth: Optional[int] = None
    traceback_locals_max_length: int = 10
    traceback_locals_max_string: int = 80

    class Config(BaseSettings.Config):
        env_prefix = "logger_"



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['arkologger']

package_data = \
{'': ['*']}

install_requires = \
['pydantic>=1.10.2,<2.0.0', 'rich>=12.6.0,<13.0.0']

setup_kwargs = {
    'name': 'arko-logger',
    'version': '0.1.1',
    'description': 'A logger.',
    'long_description': '# arko-logger\n\n一个 logger ， 用于 ArkoClub 的项目',
    'author': 'Karako',
    'author_email': 'karakohear@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
